@@ -384,7 +384,7 @@ class DBAPIRequest(RequestSessionBase):
 
     @deprecated('[3.8] use direct access to req.session.data dictionary')
     def session_data(self):
-        """return a dictionnary containing session data"""
+        """return a dictionary containing session data"""
         return self.session.data
 
     @deprecated('[3.8] use direct access to req.session.data dictionary')
@@ -659,9 +659,9 @@ class Connection(object):
         """return value associated to key in the session's data dictionary or
         session's transaction's data if `txdata` is true.
 
-        If pop is True, value will be removed from the dictionnary.
+        If pop is True, value will be removed from the dictionary.
 
-        If key isn't defined in the dictionnary, value specified by the
+        If key isn't defined in the dictionary, value specified by the
         `default` argument will be returned.
         """
         return self._repo.get_shared_data(self.sessionid, key, default, pop, txdata)
