@@ -256,6 +256,9 @@ class Transition(BaseTransition):
     """customized class for Transition entities"""
     __regid__ = 'Transition'
 
+    def dc_long_title(self):
+        return '%s (%s)' % (self.name, self._cw._(self.name))
+
     def destination(self, entity):
         try:
             return self.destination_state[0]
@@ -345,6 +348,9 @@ class State(AnyEntity):
     fetch_attrs, cw_fetch_order = fetch_config(['name'])
     rest_attr = 'eid'
 
+    def dc_long_title(self):
+        return '%s (%s)' % (self.name, self._cw._(self.name))
+
     @property
     def workflow(self):
         # take care, may be missing in multi-sources configuration
