@@ -481,7 +481,9 @@ class Entity(AppObject):
             assert eschema.has_relation(attr, role), '%s %s not found on %s' % (attr, role, eschema)
             rschema = eschema.subjrels[attr] if role == 'subject' else eschema.objrels[attr]
             if not rschema.final and isinstance(value, (tuple, list, set, frozenset)):
-                if len(value) == 1:
+                if len(value) == 0:
+                    continue # avoid crash with empty IN clause
+                elif len(value) == 1:
                     value = iter(value).next()
                 else:
                     # prepare IN clause
@@ -633,11 +635,12 @@ class Entity(AppObject):
         mainattr, needcheck = self.cw_rest_attr_info()
         etype = str(self.e_schema)
         path = etype.lower()
+        fallback = False
         if mainattr != 'eid':
             value = getattr(self, mainattr)
             if not can_use_rest_path(value):
                 mainattr = 'eid'
-                path += '/eid'
+                path = None
             elif needcheck:
                 # make sure url is not ambiguous
                 try:
@@ -648,12 +651,16 @@ class Entity(AppObject):
                     nbresults = self.__unique = self._cw.execute(rql, {'value' : value})[0][0]
                 if nbresults != 1: # ambiguity?
                     mainattr = 'eid'
-                    path += '/eid'
+                    path = None
         if mainattr == 'eid':
             if use_ext_eid:
                 value = self.cw_metainformation()['extid']
             else:
                 value = self.eid
+        if path is None:
+            # fallback url: <base-url>/<eid> url is used as cw entities uri,
+            # prefer it to <base-url>/<etype>/eid/<eid>
+            return unicode(value)
         return '%s/%s' % (path, self._cw.url_quote(value))
 
     def cw_attr_metadata(self, attr, metadata):
