@@ -641,8 +641,9 @@ class multi_columns_rset(multi_lines_rset):
 
     @lltrace
     def __call__(self, cls, req, rset=None, **kwargs):
-        # 'or 0' since we *must not* return None
-        return rset and self.match_expected(len(rset.rows[0])) or 0
+        # 'or 0' since we *must not* return None. Also don't use rset.rows so
+        # this selector will work if rset is a simple list of list.
+        return rset and self.match_expected(len(rset[0])) or 0
 
 
 class paginated_rset(Selector):
