@@ -492,6 +492,8 @@ class Repository(object):
             results['%s_cache_hit' % title] =  hits
             results['%s_cache_miss' % title] = misses
             results['%s_cache_hit_percent' % title] = (hits * 100) / (hits + misses)
+        results['type_source_cache_size'] = len(self._type_source_cache)
+        results['extid_cache_size'] = len(self._extid_cache)
         results['sql_no_cache'] = self.system_source.no_cache
         results['nb_open_sessions'] = len(self._sessions)
         results['nb_active_threads'] = threading.activeCount()
@@ -500,6 +502,43 @@ class Repository(object):
         results['threads'] = ', '.join(sorted(str(t) for t in threading.enumerate()))
         return results
 
+    def gc_stats(self, nmax=20):
+        """Return a dictionary containing some statistics about the repository
+        memory usage.
+
+        This is a public method, not requiring a session id.
+
+        nmax is the max number of (most) referenced object returned as
+        the 'referenced' result
+        """
+
+        from cubicweb._gcdebug import gc_info
+        from cubicweb.appobject import AppObject
+        from cubicweb.rset import ResultSet
+        from cubicweb.dbapi import Connection, Cursor
+        from cubicweb.web.request import CubicWebRequestBase
+        from rql.stmts import Union
+
+        lookupclasses = (AppObject,
+                         Union, ResultSet,
+                         Connection, Cursor,
+                         CubicWebRequestBase)
+        try:
+            from cubicweb.server.session import Session, InternalSession
+            lookupclasses += (InternalSession, Session)
+        except ImportError:
+            pass # no server part installed
+
+        results = {}
+        counters, ocounters, garbage = gc_info(lookupclasses,
+                                               viewreferrersclasses=())
+        values = sorted(counters.iteritems(), key=lambda x: x[1], reverse=True)
+        results['lookupclasses'] = values
+        values = sorted(ocounters.iteritems(), key=lambda x: x[1], reverse=True)[:nmax]
+        results['referenced'] = values
+        results['unreachable'] = len(garbage)
+        return results
+
     def get_schema(self):
         """Return the instance schema.
 
@@ -766,9 +805,9 @@ class Repository(object):
         """return value associated to key in the session's data dictionary or
         session's transaction's data if `txdata` is true.
 
-        If pop is True, value will be removed from the dictionnary.
+        If pop is True, value will be removed from the dictionary.
 
-        If key isn't defined in the dictionnary, value specified by the
+        If key isn't defined in the dictionary, value specified by the
         `default` argument will be returned.
         """
         session = self._get_session(sessionid, setcnxset=False)
@@ -989,11 +1028,11 @@ class Repository(object):
         for eid in eids:
             try:
                 etype, uri, extid, auri = etcache.pop(typed_eid(eid)) # may be a string in some cases
-                rqlcache.pop('%s X WHERE X eid %s' % (etype, eid), None)
+                rqlcache.pop( ('%s X WHERE X eid %s' % (etype, eid),), None)
                 extidcache.pop((extid, uri), None)
             except KeyError:
                 etype = None
-            rqlcache.pop('Any X WHERE X eid %s' % eid, None)
+            rqlcache.pop( ('Any X WHERE X eid %s' % eid,), None)
             for source in self.sources:
                 source.clear_eid_cache(eid, etype)
 
