@@ -614,12 +614,10 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
         etype = entities[0].__regid__
         for attr, storage in self._storages.get(etype, {}).items():
             for entity in entities:
-                try:
-                    edited = entity.cw_edited
-                except AttributeError:
-                    assert event == 'deleted'
-                    getattr(storage, 'entity_deleted')(entity, attr)
+                if event == 'deleted':
+                    storage.entity_deleted(entity, attr)
                 else:
+                    edited = entity.cw_edited
                     if attr in edited:
                         handler = getattr(storage, 'entity_%s' % event)
                         to_restore = handler(entity, attr)
@@ -1459,8 +1457,8 @@ def sql_schema(driver):
 CREATE TABLE entities (
   eid INTEGER PRIMARY KEY NOT NULL,
   type VARCHAR(64) NOT NULL,
-  source VARCHAR(64) NOT NULL,
-  asource VARCHAR(64) NOT NULL,
+  source VARCHAR(128) NOT NULL,
+  asource VARCHAR(128) NOT NULL,
   mtime %s NOT NULL,
   extid VARCHAR(256)
 );;
@@ -1471,7 +1469,7 @@ CREATE INDEX entities_extid_idx ON entities(extid);;
 CREATE TABLE deleted_entities (
   eid INTEGER PRIMARY KEY NOT NULL,
   type VARCHAR(64) NOT NULL,
-  source VARCHAR(64) NOT NULL,
+  source VARCHAR(128) NOT NULL,
   dtime %s NOT NULL,
   extid VARCHAR(256)
 );;
@@ -1586,9 +1584,11 @@ class LoginPasswordAuthentifier(BaseAuthentifier):
                 pwd = rset[0][0]
             except IndexError:
                 raise AuthenticationError('bad login')
+            if pwd is None:
+                # if pwd is None but a password is provided, something is wrong
+                raise AuthenticationError('bad password')
             # passwords are stored using the Bytes type, so we get a StringIO
-            if pwd is not None:
-                args['pwd'] = Binary(crypt_password(password, pwd.getvalue()[:2]))
+            args['pwd'] = Binary(crypt_password(password, pwd.getvalue()))
         # get eid from login and (crypted) password
         rset = self.source.syntax_tree_search(session, self._auth_rqlst, args)
         try:
@@ -1773,8 +1773,10 @@ class DatabaseIndependentBackupRestore(object):
         versions = set(self._get_versions())
         if file_versions != versions:
             self.logger.critical('Unable to restore : versions do not match')
-            self.logger.critical('Expected:\n%s', '\n'.join(list(sorted(versions))))
-            self.logger.critical('Found:\n%s', '\n'.join(list(sorted(file_versions))))
+            self.logger.critical('Expected:\n%s', '\n'.join('%s : %s' % (cube, ver)
+                                                            for cube, ver in sorted(versions)))
+            self.logger.critical('Found:\n%s', '\n'.join('%s : %s' % (cube, ver)
+                                                         for cube, ver in sorted(file_versions)))
             raise ValueError('Unable to restore : versions do not match')
         table_chunks = {}
         for name in archive.namelist():
