@@ -79,7 +79,12 @@ def _extract_eid_consts(plan, rqlst):
     checkread = session.read_security
     eschema = session.vreg.schema.eschema
     for rel in rqlst.where.get_nodes(Relation):
-        if rel.r_type == 'eid' and not rel.neged(strict=True):
+        # only care for 'eid' relations ...
+        if (rel.r_type == 'eid'
+            # ... that are not part of a NOT clause ...
+            and not rel.neged(strict=True)
+            # ... and where eid is specified by '=' operator.
+            and rel.children[1].operator == '='):
             lhs, rhs = rel.get_variable_parts()
             if isinstance(rhs, Constant):
                 eid = typed_eid(rhs.eval(plan.args))
@@ -392,7 +397,8 @@ class OneFetchStep(LimitOffsetMixIn, Step):
         # cachekey
         if inputmap or self.plan.cache_key is None:
             cachekey = None
-        # union may have been splited into subqueries, rebuild a cache key
+        # union may have been splited into subqueries, in which case we can't
+        # use plan.cache_key, rebuild a cache key
         elif isinstance(self.plan.cache_key, tuple):
             cachekey = list(self.plan.cache_key)
             cachekey[0] = union.as_string()
