@@ -196,6 +196,7 @@ class MigrationCommandsTC(CubicWebTC):
         self.assertFalse('filed_under2' in self.schema)
         self.mh.cmd_add_entity_type('Folder2')
         self.assertTrue('Folder2' in self.schema)
+        self.assertTrue('Old' in self.schema)
         self.assertTrue(self.execute('CWEType X WHERE X name "Folder2"'))
         self.assertTrue('filed_under2' in self.schema)
         self.assertTrue(self.execute('CWRType X WHERE X name "filed_under2"'))
@@ -209,8 +210,10 @@ class MigrationCommandsTC(CubicWebTC):
                            'modification_date', 'name', 'owned_by'])
         self.assertEqual([str(rs) for rs in self.schema['Folder2'].object_relations()],
                           ['filed_under2', 'identity'])
+        # Old will be missing as it has been renamed into 'New' in the migrated
+        # schema while New hasn't been added here.
         self.assertEqual(sorted(str(e) for e in self.schema['filed_under2'].subjects()),
-                          sorted(str(e) for e in self.schema.entities() if not e.final))
+                         sorted(str(e) for e in self.schema.entities() if not e.final and e != 'Old'))
         self.assertEqual(self.schema['filed_under2'].objects(), ('Folder2',))
         eschema = self.schema.eschema('Folder2')
         for cstr in eschema.rdef('name').constraints:
@@ -234,13 +237,22 @@ class MigrationCommandsTC(CubicWebTC):
         self.assertFalse(self.execute('State X WHERE NOT X state_of WF'))
         self.assertFalse(self.execute('Transition X WHERE NOT X transition_of WF'))
 
+    def test_rename_entity_type(self):
+        entity = self.mh.create_entity('Old', name=u'old')
+        self.repo.type_and_source_from_eid(entity.eid)
+        self.mh.cmd_rename_entity_type('Old', 'New')
+        self.mh.cmd_rename_attribute('New', 'name', 'new_name')
+
     def test_add_drop_relation_type(self):
         self.mh.cmd_add_entity_type('Folder2', auto=False)
         self.mh.cmd_add_relation_type('filed_under2')
         self.schema.rebuild_infered_relations()
         self.assertTrue('filed_under2' in self.schema)
+        # Old will be missing as it has been renamed into 'New' in the migrated
+        # schema while New hasn't been added here.
         self.assertEqual(sorted(str(e) for e in self.schema['filed_under2'].subjects()),
-                          sorted(str(e) for e in self.schema.entities() if not e.final))
+                         sorted(str(e) for e in self.schema.entities()
+                                if not e.final and e != 'Old'))
         self.assertEqual(self.schema['filed_under2'].objects(), ('Folder2',))
         self.mh.cmd_drop_relation_type('filed_under2')
         self.assertFalse('filed_under2' in self.schema)
