@@ -81,6 +81,14 @@ jQuery.extend(cw, {
             parent.removeChild(dest);
         }
         return src;
+    },
+
+    sortValueExtraction: function (node) {
+	var sortvalue = jQuery(node).attr('cubicweb:sortvalue');
+	if (sortvalue === undefined) {
+	    return '';
+	}
+	return cw.evalJSON(sortvalue);
     }
 });
 
