@@ -63,7 +63,7 @@ def list_form_param(form, param, pop=False):
     * if the parameter is already a list or tuple, just skip internal
       markers
 
-    if pop is True, the parameter is removed from the form dictionnary
+    if pop is True, the parameter is removed from the form dictionary
     """
     if pop:
         try:
@@ -97,7 +97,7 @@ class CubicWebRequestBase(DBAPIRequest):
         self.html_headers = HTMLHead(self)
         # form parameters
         self.setup_params(form)
-        # dictionnary that may be used to store request data that has to be
+        # dictionary that may be used to store request data that has to be
         # shared among various components used to publish the request (views,
         # controller, application...)
         self.data = {}
@@ -253,7 +253,7 @@ class CubicWebRequestBase(DBAPIRequest):
         * if the parameter is already a list or tuple, just skip internal
           markers
 
-        if pop is True, the parameter is removed from the form dictionnary
+        if pop is True, the parameter is removed from the form dictionary
         """
         if form is None:
             form = self.form
@@ -540,6 +540,10 @@ class CubicWebRequestBase(DBAPIRequest):
             assert expires is None, 'both max age and expires cant be specified'
             expires = maxage + time.time()
         elif expires:
+            # we don't want to handle times before the EPOCH (cause bug on
+            # windows). Also use > and not >= else expires == 0 and Cookie think
+            # that means no expire...
+            assert expires + GMTOFFSET > date(1970, 1, 1)
             expires = timegm((expires + GMTOFFSET).timetuple())
         else:
             expires = None
@@ -554,11 +558,7 @@ class CubicWebRequestBase(DBAPIRequest):
             warn('[3.13] remove_cookie now take only a name as argument',
                  DeprecationWarning, stacklevel=2)
             name = bwcompat
-        self.set_cookie(name, '', maxage=0,
-                        # substracting GMTOFFSET because set_cookie
-                        # expects a localtime and we don't want to
-                        # handle times before the EPOCH
-                        expires=date(1970, 1, 1) - GMTOFFSET) 
+        self.set_cookie(name, '', maxage=0, expires=date(2000, 1, 1))
 
     def set_content_type(self, content_type, filename=None, encoding=None):
         """set output content type for this request. An optional filename
