@@ -23,7 +23,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 import logging
-from itertools import repeat, chain
+from itertools import repeat
 from logilab.mtconverter import xml_escape
 from logilab.common.decorators import cachedproperty
 
@@ -47,6 +47,8 @@ _abaa.tag_object_of(('CWSourceSchemaConfig', 'cw_host_config_of', '*'), False)
 _abaa.tag_object_of(('CWDataImport', 'cw_import_of', '*'), False)
 
 _afs = uicfg.autoform_section
+_afs.tag_attribute(('CWSource', 'latest_retrieval'), 'main', 'hidden')
+_afs.tag_attribute(('CWSource', 'in_synchronization'), 'main', 'hidden')
 _afs.tag_object_of(('*', 'cw_for_source', 'CWSource'), 'main', 'hidden')
 
 _affk = uicfg.autoform_field_kwargs
@@ -136,7 +138,7 @@ class CWSourceMappingTab(EntityView):
             errors = zip(repeat(_('error')), checker.errors)
             warnings = zip(repeat(_('warning')), checker.warnings)
             infos = zip(repeat(_('warning')), checker.infos)
-            self.wview('pyvaltable', pyvalue=chain(errors, warnings, infos))
+            self.wview('pyvaltable', pyvalue=errors + warnings + infos)
 
 
 class MappingChecker(object):
@@ -371,8 +373,9 @@ class LogTableLayout(tableview.TableLayout):
         w(u'<label>%s</label>' % self._cw._(u'Message threshold'))
         w(u'<select class="log_filter" onchange="filterLog(\'%s\', this.options[this.selectedIndex].value)">'
           % self.view.domid)
-        for level in ('Debug', 'Info', 'Warning', 'Error', 'Fatal'):
-            w('<option value="%s">%s</option>' % (level, self._cw._(level)))
+        for level in ('DEBUG', 'INFO', 'WARNING', 'ERROR', 'FATAL'):
+            w('<option value="%s">%s</option>' % (level.capitalize(),
+                                                  self._cw._(level)))
         w(u'</select>')
         w(u'</fieldset></form>')
         super(LogTableLayout, self).render_table(w, actions, paginate)
@@ -419,7 +422,9 @@ class LogTable(pyviews.PyValTableView):
     class URLRenderer(pyviews.PyValTableColRenderer):
         def render_cell(self, w, rownum):
             url = self.data[rownum][1]
-            w(url and tags.a(url, href=url) or u'&#160;')
+            if url and url.startswith('http'):
+                url = tags.a(url, href=url)
+            w(url or u'&#160;')
 
     class LineRenderer(pyviews.PyValTableColRenderer):
         def render_cell(self, w, rownum):
@@ -458,9 +463,9 @@ class LogTable(pyviews.PyValTableView):
                     w(u'</div>')
 
     column_renderers = {0: SeverityRenderer(),
-                        1: URLRenderer(),
-                        2: LineRenderer(),
-                        3: MessageRenderer(),
+                        1: URLRenderer(sortable=False),
+                        2: LineRenderer(sortable=False),
+                        3: MessageRenderer(sortable=False),
                         }
 
 
